# Window Blinds RPi

PyPi Module: https://pypi.org/project/window-blinds-rpi/ run in terminal: pip install window-blinds-rpi

Docker:

docker run --privileged --init -d --name="home-assistant" -v /home/pi/homeassistant:/config --net=host homeassistant/raspberrypi3-homeassistant:stable

HomeAssistant:
